import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:flutter/src/widgets/framework.dart';
import 'package:gmalpha_flutter/base/base.dart';
import 'package:gmalpha_flutter/macros/ALColors.dart';
import 'package:gmalpha_flutter/model/setting_model.dart';
import 'package:provide/provide.dart';
import 'package:flutter_boost/flutter_boost.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class SettingPage extends PageProvideNode {
  final provide = new SettingProvide();

  SettingPage(Map args) {
    mProviders.provide(Provider<SettingProvide>.value(provide));
    provide.init(args);
    print(args);
  }

  @override
  Widget buildContent(BuildContext context) => _HomeContentPage(provide);
}

class _HomeContentPage extends StatefulWidget {
  SettingProvide provide;

  _HomeContentPage(this.provide);

  @override
  State<StatefulWidget> createState() {
    return _HomeContentState();
  }
}

class _HomeContentState extends State<_HomeContentPage> {
  SettingProvide _provide;
  var screenUtil;
  TextEditingController textEditingController = TextEditingController();

  @override
  void initState() {
    super.initState();
    _provide ??= widget.provide;
  }

  @override
  void dispose() {
    super.dispose();
    textEditingController.dispose();
  }

  @override
  Widget build(BuildContext context) {
//    if (screenUtil == null) {
//      screenUtil = new ScreenUtil(width: 375, height: 667)..init(context);
//    }
    return Scaffold(
      appBar: new AppBar(
        backgroundColor: Color(0xFFffffff),
        elevation: 0,
        brightness: Brightness.light,
        leading: new GestureDetector(
            child: new ImageIcon(
              AssetImage('images/nav_back.png'),
              color: ALColors.Color323232,
            ),
            onTap: () {
              FlutterBoost.singleton.closePageForContext(context);
            }),
        actions: <Widget>[
          Container(
              height: double.infinity,
              padding: EdgeInsets.fromLTRB(0, 0, 30, 0),
              child: Center(child: Provide(
                  builder: (BuildContext c, Widget w, SettingProvide pro) {
                return pro.isModifyAll
                    ? Text(
                        "保存",
                        style:
                            TextStyle(fontSize: 14, color: Color(0xffC4C4C4)),
                      )
                    : Text(
                        "保存",
                        style: TextStyle(fontSize: 14, color: Colors.black),
                      );
              }))),
        ],
      ),
      body: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          Container(
            padding: EdgeInsets.fromLTRB(29, 10, 0, 0),
            child: Text(
              "设置",
              style: TextStyle(fontSize: 30, color: Color(0xff323232)),
            ),
          ),
          Container(
            padding: EdgeInsets.fromLTRB(29, 33, 0, 33),
            child: Container(
              width: 128,
              height: 128,
              child: Stack(
                alignment: AlignmentDirectional.bottomEnd,
                children: <Widget>[
                  Provide(builder:
                      (BuildContext context, Widget child, SettingProvide pro) {
                    return pro.headUrl == null
                        ? Image.asset("images/icon_default_head.png")
                        : ClipOval(
                            child: CachedNetworkImage(
                              imageUrl: pro.headUrl,
                              placeholder: (context, url) {
                                return Image.asset(
                                    "images/icon_default_head.png");
                              },
                            ),
                          );
                  }),
                  Image.asset("images/camera.png"),
                ],
              ),
            ),
          ),
          Container(
              height: 240,
              child: Provide(
                  builder: (BuildContext c, Widget w, SettingProvide pro) {
                return ListView.separated(
                  padding: EdgeInsets.fromLTRB(30, 0, 30, 0),
                  itemCount: pro.listSize,
                  itemBuilder: (BuildContext context, int index) {
                    return Provide(builder: (BuildContext context, Widget child,
                        SettingProvide pro) {
                      if (index == 0) {
                        return specialOneItem("昵称", index);
                      } else if (index == 1) {
                        return ListItemView(context, "国家", pro.city, index);
                      } else if (index == 2) {
                        if (pro.bindIns) {
                          return ListItemView(
                              context, "我的Instagram账号", pro.email, index);
                        } else {
                          return ListItemView(context, "意见与建议", "", index);
                        }
                      } else if (index == 3) {
                        return ListItemView(context, "意见与建议", "", index);
                      }
                    });
                  },
                  separatorBuilder: (BuildContext context, int index) {
                    return new Divider(
                      height: 1.0,
                      color: Color(0xffE4E4E4),
                    );
                  },
                );
              })),
          Container(
            padding: EdgeInsets.fromLTRB(30, 0, 30, 0),
            child: Divider(
              height: 1,
              indent: 0.0,
              color: Color(0xffE4E4E4),
            ),
          ),
          Expanded(
            child: Container(),
            flex: 56,
          ),
          Container(
            width: double.maxFinite,
            padding: EdgeInsets.fromLTRB(30, 0, 30, 0),
            child: OutlineButton(
              child: Text(
                "退出登入",
                style: TextStyle(color: Color(0xff323232), fontSize: 14),
              ),
              onPressed: () => _provide.quitLogin(),
            ),
          ),
          Expanded(
            child: Container(),
            flex: 30,
          ),
        ],
      ),
    );
  }

  ListItemView(BuildContext context, String left, String right, int index) {
    return Container(
        height: 60,
        child: GestureDetector(
          onTap: onListItemTap(index),
          child: Row(
            children: <Widget>[
              Center(
                child: Text(
                  left,
                  style: TextStyle(fontSize: 13, color: Color(0xff323232)),
                ),
              ),
              Expanded(
                child: Container(),
                flex: 1,
              ),
              Center(
                  child: right != null
                      ? Text(
                          right,
                          style:
                              TextStyle(fontSize: 13, color: Color(0xff323232)),
                        )
                      : Container()),
              Center(child: Image.asset("images/right_arrow.png"))
            ],
          ),
        ));
  }

  specialOneItem(String left, int index) {
    return Container(
      height: 60,
      child: GestureDetector(
        onTap: onListItemTap(index),
        child: Row(
          children: <Widget>[
            Center(
              child: Text(
                left,
                style: TextStyle(fontSize: 13, color: Color(0xff323232)),
              ),
            ),
            Expanded(
                child: Container(
                    width: double.maxFinite,
                    child: Provide(builder:
                        (BuildContext context, Widget w, SettingProvide pro) {
                      return TextField(
                          controller: textEditingController,
                          textAlign: TextAlign.end,
                          style:
                              TextStyle(fontSize: 13, color: Color(0xff323232)),
                          maxLines: 1,
                          showCursor: false,
                          onEditingComplete: () {
                            pro.tempName = textEditingController.text;
                            pro.setSaveBtnStatus();
                          },
                          decoration: InputDecoration(
                              border: InputBorder.none,
                              hintText: pro.tempName,
                              hintStyle: TextStyle(
                                  fontSize: 13, color: Color(0xff323232))));
                    }))),
          ],
        ),
      ),
    );
  }

  onListItemTap(int index) {
    if (index == 1) {
      //点击国家
      _provide.clickCity();
    } else if (index == 2) {
      //ins
      _provide.clickIns();
    } else if (index == 3) {
      //意见
      _provide.clickArguement();
    }
  }
}
